summaryrefslogtreecommitdiff
path: root/muse2/muse/ctrl
diff options
context:
space:
mode:
Diffstat (limited to 'muse2/muse/ctrl')
-rw-r--r--muse2/muse/ctrl/CMakeLists.txt11
-rw-r--r--muse2/muse/ctrl/ctrlcanvas.cpp69
-rw-r--r--muse2/muse/ctrl/ctrlcanvas.h19
-rw-r--r--muse2/muse/ctrl/ctrledit.cpp19
-rw-r--r--muse2/muse/ctrl/ctrledit.h15
-rw-r--r--muse2/muse/ctrl/ctrlpanel.cpp49
-rw-r--r--muse2/muse/ctrl/ctrlpanel.h24
7 files changed, 151 insertions, 55 deletions
diff --git a/muse2/muse/ctrl/CMakeLists.txt b/muse2/muse/ctrl/CMakeLists.txt
index ca921775..f467b822 100644
--- a/muse2/muse/ctrl/CMakeLists.txt
+++ b/muse2/muse/ctrl/CMakeLists.txt
@@ -3,10 +3,12 @@
# Linux Music Editor
# $Id:$
#
-# Copyright (C) 2002-2006 by Werner Schweer and others
+# Copyright (C) 1999-2011 by Werner Schweer and others
#
# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2.
+# it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +16,9 @@
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# along with this program; if not, write to the
+# Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#=============================================================================
##
diff --git a/muse2/muse/ctrl/ctrlcanvas.h b/muse2/muse/ctrl/ctrlcanvas.h
index e6864003..c9baf752 100644
--- a/muse2/muse/ctrl/ctrlcanvas.h
+++ b/muse2/muse/ctrl/ctrlcanvas.h
@@ -3,6 +3,21 @@
// Linux Music Editor
// $Id: ctrlcanvas.h,v 1.7.2.4 2009/06/01 20:15:53 spamatica Exp $
// (C) Copyright 1999 Werner Schweer (ws@seh.de)
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; version 2 of
+// the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+//
//=========================================================
#ifndef __CTRLCANVAS_H__
@@ -80,7 +95,7 @@ class CEventList: public std::list<CEvent*> {
// CtrlCanvas
//---------------------------------------------------------
-class CtrlCanvas : public View {
+class CtrlCanvas : public MusEWidget::View {
Q_OBJECT
MidiEditor* editor;
@@ -138,7 +153,7 @@ class CtrlCanvas : public View {
DragMode drag;
QRect lasso;
QPoint start;
- Tool tool;
+ MusEWidget::Tool tool;
unsigned pos[3];
int curDrumInstrument; //Used by the drum-editor to view velocity of only one key (one drum)
diff --git a/muse2/muse/ctrl/ctrledit.cpp b/muse2/muse/ctrl/ctrledit.cpp
index c4e33822..61f87d28 100644
--- a/muse2/muse/ctrl/ctrledit.cpp
+++ b/muse2/muse/ctrl/ctrledit.cpp
@@ -3,6 +3,21 @@
// Linux Music Editor
// $Id: ctrledit.cpp,v 1.4.2.2 2009/02/02 21:38:00 terminator356 Exp $
// (C) Copyright 1999 Werner Schweer (ws@seh.de)
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; version 2 of
+// the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+//
//=========================================================
#include <stdio.h>
@@ -40,12 +55,12 @@ CtrlEdit::CtrlEdit(QWidget* parent, MidiEditor* e, int xmag,
QHBoxLayout* hbox = new QHBoxLayout;
panel = new CtrlPanel(0, e, "panel");
canvas = new CtrlCanvas(e, 0, xmag, "ctrlcanvas", panel);
- QWidget* vscale = new VScale;
+ QWidget* vscale = new MusEWidget::VScale;
hbox->setContentsMargins(0, 0, 0, 0);
hbox->setSpacing (0);
- canvas->setOrigin(-(config.division/4), 0);
+ canvas->setOrigin(-(MusEConfig::config.division/4), 0);
canvas->setMinimumHeight(50);
diff --git a/muse2/muse/ctrl/ctrledit.h b/muse2/muse/ctrl/ctrledit.h
index c5f5935e..e9ab3a52 100644
--- a/muse2/muse/ctrl/ctrledit.h
+++ b/muse2/muse/ctrl/ctrledit.h
@@ -3,6 +3,21 @@
// Linux Music Editor
// $Id: ctrledit.h,v 1.4.2.1 2008/05/21 00:28:53 terminator356 Exp $
// (C) Copyright 1999 Werner Schweer (ws@seh.de)
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; version 2 of
+// the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+//
//=========================================================
#ifndef __CTRL_EDIT_H__
diff --git a/muse2/muse/ctrl/ctrlpanel.h b/muse2/muse/ctrl/ctrlpanel.h
index 3f6de205..0376a245 100644
--- a/muse2/muse/ctrl/ctrlpanel.h
+++ b/muse2/muse/ctrl/ctrlpanel.h
@@ -3,6 +3,21 @@
// Linux Music Editor
// $Id: ctrlpanel.h,v 1.2.2.5 2009/06/10 00:34:59 terminator356 Exp $
// (C) Copyright 1999-2001 Werner Schweer (ws@seh.de)
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; version 2 of
+// the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+//
//=========================================================
#ifndef __CTRL_PANEL_H__
@@ -14,9 +29,12 @@ class MidiController;
class QPushButton;
-class MidiEditor;
+namespace MusEWidget {
class Knob;
class DoubleLabel;
+}
+
+class MidiEditor;
class MidiPort;
class MidiTrack;
@@ -35,8 +53,8 @@ class CtrlPanel: public QWidget {
MidiController* _ctrl;
int _dnum;
bool inHeartBeat;
- Knob* _knob;
- DoubleLabel* _dl;
+ MusEWidget::Knob* _knob;
+ MusEWidget::DoubleLabel* _dl;
int _val;
diff --git a/muse2/muse/ctrl/ctrlcanvas.cpp b/muse2/muse/ctrl/ctrlcanvas.cpp
index 68e29f20..7c77a836 100644
--- a/muse2/muse/ctrl/ctrlcanvas.cpp
+++ b/muse2/muse/ctrl/ctrlcanvas.cpp
@@ -3,6 +3,21 @@
// Linux Music Editor
// $Id: ctrlcanvas.cpp,v 1.15.2.10 2009/11/14 03:37:48 terminator356 Exp $
// (C) Copyright 1999 Werner Schweer (ws@seh.de)
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; version 2 of
+// the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+//
//=========================================================
#include <stdio.h>
@@ -184,10 +199,10 @@ CtrlCanvas::CtrlCanvas(MidiEditor* e, QWidget* parent, int xmag,
const char* name, CtrlPanel* pnl) : View(parent, xmag, 1, name)
{
setBg(Qt::white);
- setFont(config.fonts[3]);
+ setFont(MusEConfig::config.fonts[3]);
editor = e;
drag = DRAG_OFF;
- tool = PointerTool;
+ tool = MusEWidget::PointerTool;
pos[0] = 0;
pos[1] = 0;
pos[2] = 0;
@@ -212,7 +227,7 @@ CtrlCanvas::CtrlCanvas(MidiEditor* e, QWidget* parent, int xmag,
setCurTrackAndPart();
}
connect(song, SIGNAL(songChanged(int)), SLOT(songChanged(int)));
- connect(muse, SIGNAL(configChanged()), SLOT(configChanged()));
+ connect(MusEGlobal::muse, SIGNAL(configChanged()), SLOT(configChanged()));
curDrumInstrument = editor->curDrumInstrument();
//printf("CtrlCanvas::CtrlCanvas curDrumInstrument:%d\n", curDrumInstrument);
@@ -457,7 +472,7 @@ void CtrlCanvas::songChanged(int type)
return;
if(type & SC_CONFIG)
- setFont(config.fonts[3]);
+ setFont(MusEConfig::config.fonts[3]);
bool changed = false;
if(type & (SC_CONFIG | SC_PART_MODIFIED | SC_SELECTION))
@@ -663,7 +678,7 @@ void CtrlCanvas::viewMousePressEvent(QMouseEvent* event)
return;
start = event->pos();
- Tool activeTool = tool;
+ MusEWidget::Tool activeTool = tool;
bool ctrlKey = event->modifiers() & Qt::ControlModifier;
int xpos = start.x();
@@ -672,7 +687,7 @@ void CtrlCanvas::viewMousePressEvent(QMouseEvent* event)
MidiController::ControllerType type = midiControllerType(_controller->num());
switch (activeTool) {
- case PointerTool:
+ case MusEWidget::PointerTool:
if(curPart) // p4.0.27
{
drag = DRAG_LASSO_START;
@@ -717,7 +732,7 @@ void CtrlCanvas::viewMousePressEvent(QMouseEvent* event)
break;
- case PencilTool:
+ case MusEWidget::PencilTool:
if ((!ctrlKey) && (type != MidiController::Velo)) {
drag = DRAG_NEW;
song->startUndo();
@@ -730,7 +745,7 @@ void CtrlCanvas::viewMousePressEvent(QMouseEvent* event)
}
break;
- case RubberTool:
+ case MusEWidget::RubberTool:
if (type != MidiController::Velo) {
drag = DRAG_DELETE;
song->startUndo();
@@ -738,7 +753,7 @@ void CtrlCanvas::viewMousePressEvent(QMouseEvent* event)
}
break;
- case DrawTool:
+ case MusEWidget::DrawTool:
if (drawLineMode) {
line2x = xpos;
line2y = ypos;
@@ -802,7 +817,7 @@ void CtrlCanvas::viewMouseMoveEvent(QMouseEvent* event)
default:
break;
}
- if (tool == DrawTool && drawLineMode) {
+ if (tool == MusEWidget::DrawTool && drawLineMode) {
line2x = pos.x();
line2y = pos.y();
redraw();
@@ -915,8 +930,8 @@ void CtrlCanvas::newValRamp(int x1, int y1, int x2, int y2)
int raster = editor->raster();
if (raster == 1) // set reasonable raster
{
- //raster = config.division/4;
- raster = config.division/16; // Let's use 64th notes, for a bit finer resolution. p4.0.18 Tim.
+ //raster = MusEConfig::config.division/4;
+ raster = MusEConfig::config.division/16; // Let's use 64th notes, for a bit finer resolution. p4.0.18 Tim.
useRaster = true;
}
@@ -1373,8 +1388,8 @@ void CtrlCanvas::newVal(int x1, int y1, int x2, int y2)
int raster = editor->raster();
if (raster == 1) // set reasonable raster
{
- //raster = config.division/4;
- raster = config.division/16; // Let's use 64th notes, for a bit finer resolution. p4.0.18 Tim.
+ //raster = MusEConfig::config.division/4;
+ raster = MusEConfig::config.division/16; // Let's use 64th notes, for a bit finer resolution. p4.0.18 Tim.
useRaster = true;
}
@@ -1606,14 +1621,14 @@ void CtrlCanvas::deleteVal(int x1, int x2, int)
void CtrlCanvas::setTool(int t)
{
- if (tool == Tool(t))
+ if (tool == MusEWidget::Tool(t))
return;
- tool = Tool(t);
+ tool = MusEWidget::Tool(t);
switch(tool) {
- case PencilTool:
+ case MusEWidget::PencilTool:
setCursor(QCursor(*pencilIcon, 4, 15));
break;
- case DrawTool:
+ case MusEWidget::DrawTool:
drawLineMode = false;
break;
default:
@@ -1658,7 +1673,7 @@ void CtrlCanvas::pdrawItems(QPainter& p, const QRect& rect, const MidiPart* part
//if(!event.empty() && event.selected())
p.setPen(QPen(Qt::blue, 3));
else
- p.setPen(QPen(config.ctrlGraphFg, 3));
+ p.setPen(QPen(MusEConfig::config.ctrlGraphFg, 3));
}
else
p.setPen(QPen(Qt::darkGray, 3));
@@ -1750,7 +1765,7 @@ void CtrlCanvas::pdrawItems(QPainter& p, const QRect& rect, const MidiPart* part
p.drawLine(x1, lval, tick, lval);
}
else
- p.fillRect(x1, lval, tick - x1, wh - lval, selected ? Qt::blue : config.ctrlGraphFg);
+ p.fillRect(x1, lval, tick - x1, wh - lval, selected ? Qt::blue : MusEConfig::config.ctrlGraphFg);
}
@@ -1782,8 +1797,8 @@ void CtrlCanvas::pdrawItems(QPainter& p, const QRect& rect, const MidiPart* part
p.drawLine(x1, lval, x + w, lval);
}
else
- //p.fillRect(x1, lval, (x+w) - x1, wh - lval, config.ctrlGraphFg);
- p.fillRect(x1, lval, (x+w) - x1, wh - lval, selected ? Qt::blue : config.ctrlGraphFg);
+ //p.fillRect(x1, lval, (x+w) - x1, wh - lval, MusEConfig::config.ctrlGraphFg);
+ p.fillRect(x1, lval, (x+w) - x1, wh - lval, selected ? Qt::blue : MusEConfig::config.ctrlGraphFg);
}
}
}
@@ -1896,18 +1911,18 @@ void CtrlCanvas::drawOverlay(QPainter& p)
{
QString s(_controller ? _controller->name() : QString(""));
//p.setFont(config.fonts[3]); // Use widget font instead.
p.setFont(font());
p.setPen(Qt::black);
//QFontMetrics fm(config.fonts[3]); // Use widget font metrics instead.
//int y = fm.lineSpacing() + 2;
int y = fontMetrics().lineSpacing() + 2;
p.drawText(2, y, s);
if (noEvents) {
- //p.setFont(config.fonts[3]);
+ //p.setFont(MusEConfig::config.fonts[3]);
//p.setPen(Qt::black);
//p.drawText(width()/2-100,height()/2-10, "Use shift + pencil or line tool to draw new events");
p.drawText(2 , y * 2, "Use shift + pencil or line tool to draw new events");
@@ -1921,7 +1936,7 @@ void CtrlCanvas::drawOverlay(QPainter& p)
QRect CtrlCanvas::overlayRect() const
{
//QFontMetrics fm(config.fonts[3]); // Use widget font metrics instead (and set a widget font) !!!
QFontMetrics fm(fontMetrics());
QRect r(fm.boundingRect(_controller ? _controller->name() : QString("")));
@@ -1954,7 +1969,7 @@ void CtrlCanvas::draw(QPainter& p, const QRect& rect)
// draw line tool
//---------------------------------------------------
- if (drawLineMode && (tool == DrawTool)) {
+ if (drawLineMode && (tool == MusEWidget::DrawTool)) {
p.setPen(Qt::black);
p.drawLine(line1x, line1y, line2x, line2y);
}
@@ -1896,18 +1911,18 @@ void CtrlCanvas::drawOverlay(QPainter& p)
{
QString s(_controller ? _controller->name() : QString(""));
- //p.setFont(config.fonts[3]); // Use widget font instead.
+ //p.setFont(MusEConfig::config.fonts[3]); // Use widget font instead.
p.setFont(font());
p.setPen(Qt::black);
@@ -1896,18 +1911,18 @@ void CtrlCanvas::drawOverlay(QPainter& p)
p.setFont(font());
p.setPen(Qt::black);
- //QFontMetrics fm(config.fonts[3]); // Use widget font metrics instead.
+ //QFontMetrics fm(MusEConfig::config.fonts[3]); // Use widget font metrics instead.
//int y = fm.lineSpacing() + 2;
int y = fontMetrics().lineSpacing() + 2;
@@ -1921,7 +1936,7 @@ void CtrlCanvas::drawOverlay(QPainter& p)
QRect CtrlCanvas::overlayRect() const
{
- //QFontMetrics fm(config.fonts[3]); // Use widget font metrics instead (and set a widget font) !!!
+ //QFontMetrics fm(MusEConfig::config.fonts[3]); // Use widget font metrics instead (and set a widget font) !!!
QFontMetrics fm(fontMetrics());
QRect r(fm.boundingRect(_controller ? _controller->name() : QString("")));
diff --git a/muse2/muse/ctrl/ctrlpanel.cpp b/muse2/muse/ctrl/ctrlpanel.cpp
index b70c4d65..cb18afad 100644
--- a/muse2/muse/ctrl/ctrlpanel.cpp
+++ b/muse2/muse/ctrl/ctrlpanel.cpp
@@ -3,6 +3,21 @@
// Linux Music Editor
// $Id: ctrlpanel.cpp,v 1.10.2.9 2009/06/14 05:24:45 terminator356 Exp $
// (C) Copyright 1999-2004 Werner Schweer (ws@seh.de)
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; version 2 of
+// the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+//
//=========================================================
#include <stdio.h>
@@ -72,7 +87,7 @@ CtrlPanel::CtrlPanel(QWidget* parent, MidiEditor* e, const char* name)
dbox->setContentsMargins(0, 0, 0, 0);
selCtrl = new QPushButton(tr("S"));
- selCtrl->setFont(config.fonts[3]);
+ selCtrl->setFont(MusEConfig::config.fonts[3]);
selCtrl->setFixedHeight(20);
selCtrl->setSizePolicy(
QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed));
@@ -82,7 +97,7 @@ CtrlPanel::CtrlPanel(QWidget* parent, MidiEditor* e, const char* name)
// destroy button
QPushButton* destroy = new QPushButton(tr("X"));
- destroy->setFont(config.fonts[3]);
+ destroy->setFont(MusEConfig::config.fonts[3]);
destroy->setFixedHeight(20);
destroy->setSizePolicy(
QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed));
@@ -96,7 +111,7 @@ CtrlPanel::CtrlPanel(QWidget* parent, MidiEditor* e, const char* name)
_val = CTRL_VAL_UNKNOWN;
_dnum = -1;
- _knob = new Knob;
+ _knob = new MusEWidget::Knob;
_knob->setFixedWidth(25);
_knob->setFixedHeight(25);
_knob->setToolTip(tr("manual adjust"));
@@ -106,11 +121,11 @@ CtrlPanel::CtrlPanel(QWidget* parent, MidiEditor* e, const char* name)
_knob->hide();
_knob->setAltFaceColor(Qt::red);
- _dl = new DoubleLabel(-1.0, 0.0, +127.0);
+ _dl = new MusEWidget::DoubleLabel(-1.0, 0.0, +127.0);
_dl->setPrecision(0);
_dl->setToolTip(tr("double click on/off"));
_dl->setSpecialText(tr("off"));
- _dl->setFont(config.fonts[1]);
+ _dl->setFont(MusEConfig::config.fonts[1]);
_dl->setBackgroundRole(QPalette::Mid);
_dl->setFrame(true);
_dl->setFixedWidth(36);
@@ -134,7 +149,7 @@ CtrlPanel::CtrlPanel(QWidget* parent, MidiEditor* e, const char* name)
dbox->addStretch();
dbox->addWidget(_dl);
dbox->addStretch();
- connect(heartBeatTimer, SIGNAL(timeout()), SLOT(heartBeat()));
+ connect(MusEGlobal::heartBeatTimer, SIGNAL(timeout()), SLOT(heartBeat()));
inHeartBeat = false;
setLayout(vbox);
}
@@ -169,7 +184,7 @@ void CtrlPanel::heartBeat()
int v = mp->hwCtrlState(chan, _dnum);
if(v == CTRL_VAL_UNKNOWN)
{
// DoubleLabel ignores the value if already set...
_dl->setValue(_dl->off() - 1.0);
_val = CTRL_VAL_UNKNOWN;
v = mp->lastValidHWCtrlState(chan, _dnum);
@@ -195,7 +210,7 @@ void CtrlPanel::heartBeat()
_val = v;
if(v == CTRL_VAL_UNKNOWN || ((_dnum == CTRL_PROGRAM) && ((v & 0xff) == 0xff) ))
{
// DoubleLabel ignores the value if already set...
//_dl->setValue(double(_ctrl->minVal() - 1));
_dl->setValue(_dl->off() - 1.0);
}
@@ -759,10 +774,10 @@ void CtrlPanel::ctrlPopup()
}
}
- PopupMenu* ctrlMainPop = new PopupMenu;
+ MusEWidget::PopupMenu* ctrlMainPop = new MusEWidget::PopupMenu;
//ctrlMainPop->addSeparator();
- ctrlMainPop->addAction(new MenuTitleItem(tr("Instrument-defined"), ctrlMainPop));
+ ctrlMainPop->addAction(new MusEWidget::MenuTitleItem(tr("Instrument-defined"), ctrlMainPop));
//ctrlMainPop->addAction(QIcon(*configureIcon), tr("Add ..."))->setData(max + 1);
@@ -781,7 +796,7 @@ void CtrlPanel::ctrlPopup()
//ctrlMainPop->addAction(QIcon(*midi_edit_instrumentIcon), tr("Edit instruments"))->setData(max + 2);
ctrlMainPop->addSeparator();
- ctrlMainPop->addAction(new MenuTitleItem(tr("Others"), ctrlMainPop));
+ ctrlMainPop->addAction(new MusEWidget::MenuTitleItem(tr("Others"), ctrlMainPop));
//ctrlMainPop->addAction(QIcon(*configureIcon), tr("Add ..."))->setData(max + 3);
@@ -819,8 +834,8 @@ void CtrlPanel::ctrlPopup()
}
else if (rv == max + 1) { // add new instrument controller
- PopupMenu * ctrlSubPop = new PopupMenu(this);
- ctrlSubPop->addAction(new MenuTitleItem(tr("Instrument-defined"), ctrlSubPop));
+ MusEWidget::PopupMenu * ctrlSubPop = new MusEWidget::PopupMenu(this);
+ ctrlSubPop->addAction(new MusEWidget::MenuTitleItem(tr("Instrument-defined"), ctrlSubPop));
//
// populate popup with all controllers available for
@@ -856,7 +871,7 @@ void CtrlPanel::ctrlPopup()
int rv2 = act2->data().toInt();
if (rv2 == max + 2) // edit instrument
- muse->startEditInstrument();
+ MusEGlobal::muse->startEditInstrument();
else // select new instrument control
{
MidiController* c;
@@ -888,11 +903,11 @@ void CtrlPanel::ctrlPopup()
}
//else if (rv == max + 2) // edit instrument
- // muse->startEditInstrument();
+ // MusEGlobal::muse->startEditInstrument();
else if (rv == max + 3) { // add new other controller
- PopupMenu* ctrlSubPop = new PopupMenu(this);
- ctrlSubPop->addAction(new MenuTitleItem(tr("Common Controls"), ctrlSubPop));
+ MusEWidget::PopupMenu* ctrlSubPop = new MusEWidget::PopupMenu(this);
+ ctrlSubPop->addAction(new MusEWidget::MenuTitleItem(tr("Common Controls"), ctrlSubPop));
for(int num = 0; num < 127; ++num)
if(cll->find(channel, num) == cll->end())
@@ -169,7 +184,7 @@ void CtrlPanel::heartBeat()
if(v == CTRL_VAL_UNKNOWN)
{
- // DoubleLabel ignores the value if already set...
+ // MusEWidget::DoubleLabel ignores the value if already set...
_dl->setValue(_dl->off() - 1.0);
_val = CTRL_VAL_UNKNOWN;
@@ -195,7 +210,7 @@ void CtrlPanel::heartBeat()
if(v == CTRL_VAL_UNKNOWN || ((_dnum == CTRL_PROGRAM) && ((v & 0xff) == 0xff) ))
{
- // DoubleLabel ignores the value if already set...
+ // MusEWidget::DoubleLabel ignores the value if already set...
//_dl->setValue(double(_ctrl->minVal() - 1));
_dl->setValue(_dl->off() - 1.0);